@@ -116,11 +116,13 @@ class OutboxEncryption:
         res = keyword.replace('-','_')
         res = res.replace(':','_')
         res = res.replace('.','_')
+        res = res.replace('/','_') # baru untuk versi 3.8 Python
         return res
 
     def string_replace_env(self, keyword):
         res = keyword.replace('(','')
         res = res.replace(')','')        
+        res = res.replace('/','_')        
         return res.strip()
 
     def encrypt_environ(self, plain_text):
